@@ -13,7 +13,7 @@
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.all <- function(env = solvebio:::.solveEnv, ...) {
+Dataset.all <- function(env = .solveEnv, ...) {
     .request('GET', "v2/datasets", query=list(...), env=env)
 }
 
@@ -33,7 +33,7 @@ Dataset.all <- function(env = solvebio:::.solveEnv, ...) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.retrieve <- function(id, env = solvebio:::.solveEnv) {
+Dataset.retrieve <- function(id, env = .solveEnv) {
     if (missing(id)) {
         stop("A dataset ID is required.")
     }
@@ -58,7 +58,7 @@ Dataset.retrieve <- function(id, env = solvebio:::.solveEnv) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.delete <- function(id, env = solvebio:::.solveEnv) {
+Dataset.delete <- function(id, env = .solveEnv) {
     if (missing(id)) {
         stop("A dataset ID is required.")
     }
@@ -83,7 +83,7 @@ Dataset.delete <- function(id, env = solvebio:::.solveEnv) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.template <- function(id, env = solvebio:::.solveEnv) {
+Dataset.template <- function(id, env = .solveEnv) {
     if (missing(id)) {
         stop("A dataset ID is required.")
     }
@@ -109,7 +109,7 @@ Dataset.template <- function(id, env = solvebio:::.solveEnv) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.data <- function(id, filters,  env = solvebio:::.solveEnv, ...) {
+Dataset.data <- function(id, filters,  env = .solveEnv, ...) {
     if (missing(id) || !(class(id) %in% c("Dataset", "numeric", "integer", "character"))) {
         stop("A dataset ID (or object) is required.")
     }
@@ -162,7 +162,7 @@ Dataset.data <- function(id, filters,  env = solvebio:::.solveEnv, ...) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.query <- function(id, paginate=FALSE, use_field_titles=TRUE, env = solvebio:::.solveEnv, ...) {
+Dataset.query <- function(id, paginate=FALSE, use_field_titles=TRUE, env = .solveEnv, ...) {
     params <- list(...)
     params$id <- id
     params$env <- env
@@ -211,7 +211,7 @@ Dataset.query <- function(id, paginate=FALSE, use_field_titles=TRUE, env = solve
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.fields <- function(id, env = solvebio:::.solveEnv, ...) {
+Dataset.fields <- function(id, env = .solveEnv, ...) {
     if (inherits(id, "numeric")) {
         warning("Please use string IDs instead of numeric IDs.")
     }
@@ -246,7 +246,7 @@ Dataset.fields <- function(id, env = solvebio:::.solveEnv, ...) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.facets <- function(id, facets, env = solvebio:::.solveEnv, ...) {
+Dataset.facets <- function(id, facets, env = .solveEnv, ...) {
     if (missing(facets) || is.null(facets) || facets == "") {
         stop("A list of one or more facets is required.")
     }
@@ -291,7 +291,7 @@ Dataset.facets <- function(id, facets, env = solvebio:::.solveEnv, ...) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.count <- function(id, env = solvebio:::.solveEnv, ...) {
+Dataset.count <- function(id, env = .solveEnv, ...) {
     params <- list(...)
     # Count queries should not return results
     params$limit <- 0
@@ -321,7 +321,7 @@ Dataset.count <- function(id, env = solvebio:::.solveEnv, ...) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.create <- function(vault_id, vault_parent_object_id, name, env = solvebio:::.solveEnv, ...) {
+Dataset.create <- function(vault_id, vault_parent_object_id, name, env = .solveEnv, ...) {
     if (missing(vault_id)) {
         stop("A vault ID is required.")
     }
@@ -365,7 +365,7 @@ Dataset.create <- function(vault_id, vault_parent_object_id, name, env = solvebi
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.update <- function(id, env = solvebio:::.solveEnv, ...) {
+Dataset.update <- function(id, env = .solveEnv, ...) {
     if (missing(id)) {
         stop("A dataset ID is required.")
     }
@@ -392,7 +392,7 @@ Dataset.update <- function(id, env = solvebio:::.solveEnv, ...) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.get_by_full_path <- function(full_path, env = solvebio:::.solveEnv) {
+Dataset.get_by_full_path <- function(full_path, env = .solveEnv) {
     object = Object.get_by_full_path(full_path, env=env)
 
     dataset = do.call(Dataset.retrieve, list(id=object$dataset_id, env=env))
@@ -416,7 +416,7 @@ Dataset.get_by_full_path <- function(full_path, env = solvebio:::.solveEnv) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.get_or_create_by_full_path <- function(full_path, env = solvebio:::.solveEnv, ...) {
+Dataset.get_or_create_by_full_path <- function(full_path, env = .solveEnv, ...) {
     dataset = NULL
     tryCatch({
         dataset <- Dataset.get_by_full_path(full_path=full_path, env=env)
@@ -494,7 +494,7 @@ Dataset.get_or_create_by_full_path <- function(full_path, env = solvebio:::.solv
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.activity <- function(id, follow=TRUE, env = solvebio:::.solveEnv) {
+Dataset.activity <- function(id, follow=TRUE, env = .solveEnv) {
     status <- paste('running', 'queued', 'pending', sep=',')
     tasks <- Task.all(target_object_id=id, status=status, env=env)$data
 
@@ -531,7 +531,7 @@ Dataset.activity <- function(id, follow=TRUE, env = solvebio:::.solveEnv) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.get_global_beacon_status <- function(id, raise_on_disabled = FALSE, env = solvebio:::.solveEnv) {
+Dataset.get_global_beacon_status <- function(id, raise_on_disabled = FALSE, env = .solveEnv) {
     if (missing(id)) {
         stop("A dataset ID is required.")
     }
@@ -555,7 +555,7 @@ Dataset.get_global_beacon_status <- function(id, raise_on_disabled = FALSE, env
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.enable_global_beacon <- function(id, env = solvebio:::.solveEnv) {
+Dataset.enable_global_beacon <- function(id, env = .solveEnv) {
     if (missing(id)) {
         stop("A dataset ID is required.")
     }
@@ -579,7 +579,7 @@ Dataset.enable_global_beacon <- function(id, env = solvebio:::.solveEnv) {
 #' \url{https://docs.solvebio.com/}
 #'
 #' @export
-Dataset.disable_global_beacon <- function(id, env = solvebio:::.solveEnv) {
+Dataset.disable_global_beacon <- function(id, env = .solveEnv) {
     if (missing(id)) {
         stop("A dataset ID is required.")
     }
